@@ -140,6 +140,7 @@ class Service:
                         "traefik.http.middlewares.default-headers.headers.forceSTSHeader": "true",
                         "traefik.http.middlewares.default-headers.headers.stsIncludeSubdomains": "true",
                         "traefik.http.middlewares.default-headers.headers.stsPreload": "true",
+                        "traefik.http.middlewares.default-headers.headers.sslProxyHeaders.X-FORWARDED-PROTO": "https",
                         "traefik.http.routers.traefik-secured.service": "api@internal",
                         "traefik.http.routers.traefik-secured.tls": "true",
                         "traefik.http.routers.traefik-secured.rule": "Host(`"
@@ -154,7 +155,7 @@ class Service:
                 "image": "portainer/portainer-ce:2.0.0",
                 "auto_remove": False,
                 "detach": True,
-                "entrypoint": f"/portainer -H unix:///var/run/docker.sock --templates {self.config.template_url}",
+                "entrypoint": f"/portainer -H unix:///var/run/docker.sock --templates {self.config.template_url} --admin-password {self.config.password_hash}",
                 "hostname": "portainer",
                 "labels": {
                     "backplane.enabled": "true",
@@ -186,7 +187,8 @@ class Service:
                     },
                 }
             }
-        elif self.name == "shipmate":
+
+        elif self.name == "backplane":
             pass
 
         else:
@@ -220,7 +222,7 @@ class Service:
 
     def echo(self, nl=True):
         # Target message:
-        # [traefik] running at http://traefik.127-0-0-1.nip.io
+        # [traefik] running at http://traefik.127-0-0-1.ns0.co
         message_prefix = typer.style(f"{self.name} ", bold=True)
         # message_prefix = typer.style(" ∟ ", fg=typer.colors.RED)
 
